@@ -102,7 +102,7 @@ class RevisionNumBig(ct.BigEndianStructure):
     _fields_ = [('revision', ct.c_float)]
 
 
-class Pfile(object):
+class Pfile:
     """
     This class was based on the style of code from the pfile-tools 
     package written by Nathan Vack in that we use ctypes to organize 
@@ -143,12 +143,12 @@ class Pfile(object):
                 return False
         else:
             offset = self.hdr.rhr_rdb_hdr_off_data
-            # ARC 20220209: coverage here is likey to be incomplete. This check
+            # ARC 20220209: coverage here is likely to be incomplete. This check
             # may well be redundant anyway, since revision number has
             # previously been validated in _version
             if offset in \
                     [
-                        61464,   # bjs from matlap script for ver = 9
+                        61464,   # bjs from Matlab script for ver = 9
                         66072,
                         145908,
                         149788,
@@ -180,7 +180,7 @@ class Pfile(object):
         
         if psd == 'probe-p':
             mapper = PfileMapper
-        elif psd == 'oslaser':
+        elif psd in ['oslaser', 'slaser_cni']:
             mapper = PfileMapperSlaser
         elif psd == 'presscsi':
             mapper = PfileMapper
@@ -423,11 +423,11 @@ class Pfile(object):
 # ------------------------------------------------------------------------------
 
 
-class PfileMapper(object):
+class PfileMapper:
 
     def __init__(self, file_name, hdr, version, endian):
         """
-        Given a file name, its header, version number and endianess, this
+        Given a file name, its header, version number and endianness, this
         class will parse the data section of the file for the suppressed and
         unsuppressed data.  
         
@@ -578,7 +578,7 @@ class PfileMapper(object):
             xdim = int(pow(2, math.ceil(math.log(nvox[0], 2))))
             ydim = int(pow(2, math.ceil(math.log(nvox[1], 2))))
 
-            if(ydim > xdim):
+            if (ydim > xdim):
                 fov_spatial_resolution = dfov / ydim
             else:
                 fov_spatial_resolution = dfov / xdim
@@ -928,7 +928,8 @@ class PfileMapper(object):
 
         return x, y, z
 
-    def get_center_from_origin(self, origin, numVoxels, voxelSpacing, dcos): 
+    @staticmethod
+    def get_center_from_origin(origin, numVoxels, voxelSpacing, dcos): 
         """
         Calculates the LPS center from the origin(toplc).
         
@@ -941,7 +942,8 @@ class PfileMapper(object):
                 center[i] += dcos[j][i] * voxelSpacing[j] * (numVoxels[j] / 2.0 - 0.5)
         return center
 
-    def get_origin_from_center(self, center, numVoxels, voxelSpacing, dcos): 
+    @staticmethod
+    def get_origin_from_center(center, numVoxels, voxelSpacing, dcos): 
         """
         Calculates the LPS origin (toplc) from the center.
         
@@ -1091,8 +1093,6 @@ class PfileMapper(object):
             self.raw_unsuppressed = None
             self.avg_unsuppressed = None
             self.phase_of_first_point_deg = None
-            
-        return
 
 
 class PfileMapperProbeSL(PfileMapper):
