@@ -3,6 +3,7 @@ Author: William Clarke <william.clarke@ndcn.ox.ac.uk>
 Copyright (C) 2020 University of Oxford
 """
 from datetime import datetime
+import re
 
 import numpy as np
 import nibabel.nicom.dicomwrappers
@@ -190,7 +191,7 @@ def multi_file_dicom(files_in, fname_out, tag, verbose):
         try:
             nifti_mrs_out.append(nifti_mrs.NIfTI_MRS(combined_data, or_used.Q44, dt_used, meta_used))
         except np.linalg.LinAlgError:
-            warnings.warn("""The quartenion passes to NIfTI_MRS was singular.
+            warnings.warn("""The quaternion passes to NIfTI_MRS was singular.
                            Most likely your slice position is not well defined. I have set it to None.""")
             nifti_mrs_out.append(nifti_mrs.NIfTI_MRS(combined_data, None, dt_used, meta_used))
 
@@ -303,6 +304,16 @@ def process_siemens_csi_vx(img, verbose):
     slices = img.csa_header['tags']['NumberOfFrames']['items'][0]
     spectral_points = img.csa_header['tags']['DataPointColumns']['items'][0]
 
+    # I think the above is sufficient, but might need to access more specific Siemens specific parameters
+    # In that case I could use the following use the full MrPhoenixProtocol sSpecPara parameters
+    # fullcsa = csar.get_csa_header(img.dcm_data, csa_type='series')
+    # xprot = parse_buffer(fullcsa['tags']['MrPhoenixProtocol']['items'][0])
+
+    # rows = int(xprot[('sSpecPara', 'lFinalMatrixSizePhase')])
+    # cols = int(xprot[('sSpecPara', 'lFinalMatrixSizeRead')])
+    # slices = int(xprot[('sSpecPara', 'lFinalMatrixSizeSlice')])
+    # spectral_points = int(xprot[('sSpecPara', 'lVectorSize')])
+
     specDataCmplx = specDataCmplx.reshape((slices, rows, cols, spectral_points))
     specDataCmplx = np.moveaxis(specDataCmplx, (0, 1, 2), (2, 1, 0))
 
@@ -483,8 +494,20 @@ def extractDicomMetadata_vx(dcmdata):
             pass
 
     # # 5.1 MRS specific Tags
-    # 'EchoTime'
-    obj.set_standard_def('EchoTime', float(dcmdata.csa_header['tags']['EchoTime']['items'][0] * 1E-3))
+    # 'EchoTime' - requires substantial extraction from the full protocol incase there are multiple
+    # sub-values, e.g. summing the three TEs of a sLAASER sequence together.
+    fullcsa = csar.get_csa_header(dcmdata.dcm_data, csa_type='series')
+    xprot = parse_buffer(fullcsa['tags']['MrPhoenixProtocol']['items'][0])
+    te_sum = 0
+    for teDx in range(128):
+        try:
+            te_sum += xprot[('alTE', str(teDx))]
+        except KeyError:
+            break
+    obj.set_standard_def('EchoTime', float(te_sum * 1E-6))
+    # Original
+    # obj.set_standard_def('EchoTime', float(dcmdata.csa_header['tags']['EchoTime']['items'][0] * 1E-3))
+
     # 'RepetitionTime'
     obj.set_standard_def('RepetitionTime', float(dcmdata.csa_header['tags']['RepetitionTime']['items'][0] / 1E3))
     # 'InversionTime'
@@ -560,7 +583,7 @@ def extractDicomMetadata_vx(dcmdata):
 
 def identify_integrated_references(img, inst_num):
     '''Heuristics for identifying integrated reference scans in known sequences.
-    Sequences handled: CMRR svs_slaserVOI_dkd
+    Sequences handled: CMRR svs_slaserVOI_dkd(2)
 
     :param img: nibable dicom image
 
@@ -577,8 +600,9 @@ def identify_integrated_references(img, inst_num):
     # Handle CMRR DKD sequence
     # https://www.cmrr.umn.edu/spectro/
     # SEMI-LASER (MRM 2011, NMB 2019) Release 2016-12
-    if xprot[('tSequenceFileName',)].strip('"').lower() == '%customerseq%\\svs_slaservoi_dkd'\
-            and xprot[('sSpecPara', 'lAutoRefScanMode')] == 8.0:
+    seq_file_name = xprot[('tSequenceFileName',)].strip('"').lower()
+    match = re.search(r'svs_slaservoi_dkd', seq_file_name)
+    if match and xprot[('sSpecPara', 'lAutoRefScanMode')] == 8.0:
         num_ref = int(xprot[('sSpecPara', 'lAutoRefScanNo')])
         num_dyn = int(xprot[('lAverages',)])
         total_dyn = num_dyn + (num_ref * 4)
